@@ -48,7 +48,7 @@ merge_tree (const char *root_dir)
   MarkupTree *tree;
   GError *error;
 
-  if (stat (root_dir, &statbuf) == 0)
+  if (g_stat (root_dir, &statbuf) == 0)
     {
       dir_mode = _gconf_mode_t_to_mode (statbuf.st_mode);
       /* dir_mode without search bits */
@@ -61,7 +61,7 @@ merge_tree (const char *root_dir)
 
     }
 
-  tree = markup_tree_get (root_dir, dir_mode, file_mode, FALSE);
+  tree = markup_tree_get (root_dir, dir_mode, file_mode, TRUE);
 
   recursively_load_subtree (tree->root);
 
@@ -71,7 +71,7 @@ merge_tree (const char *root_dir)
     {
       char *markup_file;
 
-      markup_file = markup_dir_build_file_path (tree->root, TRUE);
+      markup_file = markup_dir_build_file_path (tree->root, TRUE, NULL);
       fprintf (stderr, _("Error saving GConf tree to '%s': %s\n"),
 	       markup_file,
 	       error->message);
