@@ -185,7 +185,7 @@ gconf_backend_file(const gchar* address)
 
   g_free(back);
 
-  if (gconf_file_exists(retval))
+  if (g_file_test(retval, G_FILE_TEST_EXISTS))
     {
       g_free(file);
 
@@ -205,7 +205,7 @@ gconf_backend_file(const gchar* address)
 
       g_free(dir);
       
-      if (gconf_file_exists(retval))
+      if (g_file_test(retval, G_FILE_TEST_EXISTS))
         {
           g_free(file);
           return retval;
@@ -258,7 +258,7 @@ gconf_backend_verify_vtable (GConfBackendVTable  *vtable,
   if (!vtable)
     {
       gconf_set_error(err,
-		      GCONF_ERROR_FAILED, _("Backend `%s' failed return a vtable\n"),
+		      GCONF_ERROR_FAILED, _("Backend `%s' failed to return a vtable\n"),
 		      backend_name);
       return FALSE;
     }
