@@ -39,6 +39,7 @@
 #ifdef G_OS_WIN32
 #include <windows.h>
 #include <share.h>
+#define pipe(fds) _pipe(fds, 4096, _O_BINARY)
 #endif
 
 gboolean gconf_log_debug_messages = FALSE;
@@ -160,7 +161,7 @@ gconf_value_from_corba_value(const ConfigValue* value)
       type = GCONF_VALUE_PAIR;
       break;
     default:
-      gconf_log(GCL_DEBUG, "Invalid type in %s", G_GNUC_FUNCTION);
+      gconf_log(GCL_DEBUG, "Invalid type in %s", G_STRFUNC);
       return NULL;
     }
 
@@ -216,7 +217,7 @@ gconf_value_from_corba_value(const ConfigValue* value)
           case BInvalidVal:
             break;
           default:
-            g_warning("Bizarre list type in %s", G_GNUC_FUNCTION);
+            g_warning("Bizarre list type in %s", G_STRFUNC);
             break;
           }
 
@@ -237,7 +238,7 @@ gconf_value_from_corba_value(const ConfigValue* value)
                 if (val == NULL)
                   gconf_log(GCL_ERR, _("Couldn't interpret CORBA value for list element"));
                 else if (val->type != gconf_value_get_list_type(gval))
-                  gconf_log(GCL_ERR, _("Incorrect type for list element in %s"), G_GNUC_FUNCTION);
+                  gconf_log(GCL_ERR, _("Incorrect type for list element in %s"), G_STRFUNC);
                 else
                   list = g_slist_prepend(list, val);
                 
@@ -347,7 +348,7 @@ gconf_fill_corba_value_from_gconf_value(const GConfValue *value,
             
           default:
             cv->_u.list_value.list_type = BInvalidVal;
-            gconf_log(GCL_DEBUG, "Invalid list type in %s", G_GNUC_FUNCTION);
+            gconf_log(GCL_DEBUG, "Invalid list type in %s", G_STRFUNC);
             break;
           }
         
@@ -386,7 +387,7 @@ gconf_fill_corba_value_from_gconf_value(const GConfValue *value,
       break;
     default:
       cv->_d = InvalidVal;
-      gconf_log(GCL_DEBUG, "Unknown type in %s", G_GNUC_FUNCTION);
+      gconf_log(GCL_DEBUG, "Unknown type in %s", G_STRFUNC);
       break;
     }
 }
@@ -1880,7 +1881,7 @@ gconf_value_decode (const gchar* encoded)
         
         d = g_strtod(s, &endptr);
         if (endptr == s)
-          g_warning("Failure converting string to double in %s", G_GNUC_FUNCTION);
+          g_warning("Failure converting string to double in %s", G_STRFUNC);
         gconf_value_set_float(val, d);
       }
       break;
