@@ -189,7 +189,7 @@ static ConfigDatabase gconf_engine_get_database (GConfEngine     *conf,
 
 #define CHECK_OWNER_USE(engine)   \
   do { if ((engine)->owner && (engine)->owner_use_count == 0) \
-     g_warning ("%s: You can't use a GConfEngine that has an active GConfClient wrapper object. Use GConfClient API instead.", G_GNUC_FUNCTION);  \
+     g_warning ("%s: You can't use a GConfEngine that has an active GConfClient wrapper object. Use GConfClient API instead.", G_STRFUNC);  \
   } while (0)
 
 static void         register_engine           (GConfEngine    *conf);
@@ -1700,7 +1700,7 @@ gconf_engine_all_entries(GConfEngine* conf, const gchar* dir, GError** err)
   if (keys->_length != values->_length)
     {
       g_warning("Received unmatched key/value sequences in %s",
-                G_GNUC_FUNCTION);
+                G_STRFUNC);
       return NULL;
     }
 
@@ -2280,9 +2280,9 @@ gconf_get_config_server(gboolean start_if_not_found, GError** err)
   return server; /* return what we have, NIL or not */
 }
 
-ConfigListener listener = CORBA_OBJECT_NIL;
+static ConfigListener listener = CORBA_OBJECT_NIL;
 
-void
+static void
 gconf_detach_config_server(void)
 {  
   CORBA_Environment ev;
@@ -3182,7 +3182,7 @@ gconf_engine_get_string(GConfEngine* conf, const gchar* key,
   val = gconf_engine_get (conf, key, err);
 
   if (val == NULL)
-    return deflt ? g_strdup(deflt) : NULL;
+    return g_strdup(deflt);
   else
     {
       gchar* retval;
@@ -3193,7 +3193,7 @@ gconf_engine_get_string(GConfEngine* conf, const gchar* key,
             *err = gconf_error_new(GCONF_ERROR_TYPE_MISMATCH, _("Expected string, got %s"),
                                     gconf_value_type_to_string(val->type));
           gconf_value_free(val);
-          return deflt ? g_strdup(deflt) : NULL;
+          return g_strdup(deflt);
         }
 
       retval = gconf_value_steal_string (val);
